<?php
/*********************************************************************************
 * TimeTrex is a Payroll and Time Management program developed by
 * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by
 * the Free Software Foundation with the addition of the following permission
 * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
 * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
 * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License along
 * with this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 *
 * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
 * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Powered by TimeTrex".
 ********************************************************************************/
/*
 * $Revision: 4104 $
 * $Id: InstallSchema_1012A.class.php 4104 2011-01-04 19:04:05Z ipso $
 * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
 */

/**
 * @package Module_Install
 */
class InstallSchema_1012A extends InstallSchema_Base {

	function preInstall() {
		Debug::text('preInstall: '. $this->getVersion() , __FILE__, __LINE__, __METHOD__,9);

		return TRUE;
	}

	function postInstall() {
		global $cache;
		
		Debug::text('postInstall: '. $this->getVersion(), __FILE__, __LINE__, __METHOD__,9);
		
		//Get all pay period schedules.
		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
		$ppslf->getAll();
		if ( $ppslf->getRecordCount() > 0 ) {
			foreach( $ppslf as $pps_obj ) {
				$user_ids = $pps_obj->getUser();
				if ( is_array($user_ids) ) {
					$time_zone_arr = array();
					foreach( $user_ids as $user_id ) {
						$uplf = TTnew( 'UserPreferenceListFactory' );
						$uplf->getByUserId( $user_id );
						if ( $uplf->getRecordCount() > 0 ) {
							if ( isset($time_zone_arr[$uplf->getCurrent()->getTimeZone()]) ) {
								$time_zone_arr[$uplf->getCurrent()->getTimeZone()]++;
							} else {
								$time_zone_arr[$uplf->getCurrent()->getTimeZone()] = 1;
							}
						}
					}
					
					arsort($time_zone_arr);
					
					//Grab the first time zone, as it is most common
					foreach( $time_zone_arr as $time_zone => $count ) {				
						break;
					}
					
					if ( $time_zone != '' ) {
						//Set pay period timezone to the timezone of the majority of the users are in.
						$pps_obj->setTimeZone( $time_zone );
						if ( $pps_obj->isValid() ) {
							$pps_obj->Save();
						}
					}
				}
			}
		}
		
		Debug::text('l: '. $this->getVersion(), __FILE__, __LINE__, __METHOD__,9);
				
		return TRUE;
	}
}
?>
